@@ -32,7 +32,13 @@
  * DEFINTIIONS {{
  */
 
-const gchar *supported_sound_mime_types [] = { "audio", "video", "application/ogg", NULL };
+static const gchar *supported_sound_mime_types [] = {
+    "audio",
+    "video",
+    "application/ogg",
+    NULL
+};
+
 GHashTable *app_command_map = NULL;
 
 /*
@@ -113,7 +119,7 @@ alarm_applet_alarms_stop (AlarmApplet *applet)
 	for (l = applet->alarms; l; l = l->next) {
 		a = ALARM (l->data);
 
-        if (alarm_is_playing (a)) {
+		if (a->triggered) {
     		alarm_clear (a);
             last_stopped = a;
             n_stopped++;
@@ -670,12 +676,9 @@ alarm_applet_init (int *argc, char ***argv)
 	// TODO: Add to gconf
 	applet->snooze_mins = 5;
 
-	// Set up gconf handlers
+	// Initialize gconf
 	alarm_applet_gconf_init (applet);
 
-	// Load gconf values
-	alarm_applet_gconf_load (applet);
-
 	// Load alarms
 	alarm_applet_alarms_load (applet);
     
