@@ -176,8 +176,12 @@ alarm_applet_notification_show (AlarmApplet *applet,
     NotifyNotification *n;
     GError *error = NULL;
 
-    n = notify_notification_new_with_status_icon (summary, body, icon,
-                                                  applet->status_icon);
+    // Gotta love API breakage...
+#ifdef HAVE_LIBNOTIFY_0_7
+    n = notify_notification_new (summary, body, icon);
+#else
+    n = notify_notification_new (summary, body, icon, NULL);
+#endif
     
     if (!notify_notification_show (n, &error)) {
         g_warning ("Failed to send notification: %s", error->message);
@@ -187,6 +191,61 @@ alarm_applet_notification_show (AlarmApplet *applet,
 	g_object_unref(G_OBJECT(n));
 }
 
+void
+alarm_applet_label_update (AlarmApplet *applet)
+{
+#ifdef HAVE_APP_INDICATOR
+	GList *l;
+	Alarm *a;
+	Alarm *next_alarm = NULL;
+	struct tm *tm;
+	gchar *tmp;
+	gboolean show_label = gtk_toggle_action_get_active (applet->action_toggle_show_label);
+
+	if (!show_label) {
+		app_indicator_set_label (applet->app_indicator, NULL, NULL);
+		return;
+	}
+
+	//
+	// Show countdown
+	//
+	for (l = applet->alarms; l; l = l->next) {
+		a = ALARM (l->data);
+		if (!a->active) continue;
+
+		if (!next_alarm || a->timestamp < next_alarm->timestamp) {
+			next_alarm = a;
+		}
+	}
+
+	if (!next_alarm) {
+		// No upcoming alarms
+		app_indicator_set_label (applet->app_indicator, NULL, NULL);
+		return;
+	}
+
+	tm = alarm_get_remain (next_alarm);
+	tmp = g_strdup_printf("%02d:%02d:%02d", tm->tm_hour, tm->tm_min, tm->tm_sec);
+	app_indicator_set_label (applet->app_indicator, tmp, NULL);
+	g_free(tmp);
+
+#endif
+}
+
+/*
+ * Updates label etc
+ */
+static gboolean
+alarm_applet_ui_update (AlarmApplet *applet)
+{
+	alarm_applet_label_update (applet);
+
+	//alarm_applet_update_tooltip (applet);
+
+	return TRUE;
+}
+
 
 
 
@@ -220,6 +279,10 @@ alarm_applet_ui_init (AlarmApplet *applet)
 
     /* Initialize preferences dialog */
     prefs_init (applet);
+
+    /* Set up UI updater */
+	alarm_applet_ui_update (applet);
+	g_timeout_add_seconds (1, (GSourceFunc)alarm_applet_ui_update, applet);
 }
 
 /*
@@ -228,10 +291,19 @@ alarm_applet_ui_init (AlarmApplet *applet)
 static void
 alarm_applet_status_init (AlarmApplet *applet)
 {
+	applet->status_menu = GTK_WIDGET (gtk_builder_get_object (applet->ui, "status_menu"));
+
+#ifdef HAVE_APP_INDICATOR
+	applet->app_indicator = app_indicator_new(PACKAGE_NAME, ALARM_ICON,
+			APP_INDICATOR_CATEGORY_APPLICATION_STATUS);
+	app_indicator_set_status (applet->app_indicator, APP_INDICATOR_STATUS_ACTIVE);
+	app_indicator_set_attention_icon (applet->app_indicator, TRIGGERED_ICON);
+	app_indicator_set_menu (applet->app_indicator, GTK_MENU (applet->status_menu));
+#else
     applet->status_icon = GTK_STATUS_ICON (gtk_builder_get_object (applet->ui, "status_icon"));
-    applet->status_menu = GTK_WIDGET (gtk_builder_get_object (applet->ui, "status_menu"));
 
     gtk_status_icon_set_visible (applet->status_icon, TRUE);
+#endif
 }
 
 /*
@@ -240,26 +312,35 @@ alarm_applet_status_init (AlarmApplet *applet)
 void
 alarm_applet_status_update (AlarmApplet *applet)
 {
+#ifdef HAVE_APP_INDICATOR
+	if (applet->n_triggered > 0) {
+	    app_indicator_set_status (applet->app_indicator, APP_INDICATOR_STATUS_ATTENTION);
+	} else {
+	    app_indicator_set_status (applet->app_indicator, APP_INDICATOR_STATUS_ACTIVE);
+	}
+#else
+    if (applet->n_triggered > 0) {
+        gtk_status_icon_set_from_icon_name (applet->status_icon, TRIGGERED_ICON);
+    } else {
+        gtk_status_icon_set_from_icon_name (applet->status_icon, ALARM_ICON);
+    }
     gtk_status_icon_set_blinking (applet->status_icon, applet->n_triggered > 0);
+#endif
 }
 
 /*
  * Status icon callbacks:
  */
-
 G_MODULE_EXPORT void
 alarm_applet_status_activate (GtkStatusIcon *status_icon,
 							  gpointer       user_data)
 {
+#ifndef HAVE_APP_INDICATOR
     AlarmApplet *applet = (AlarmApplet *)user_data;
-
-    // Snooze triggered alarms if any
-    if (applet->n_triggered > 0) {
-        gtk_action_activate (applet->action_snooze_all);
-    } else {
-        // No alarms triggered, toggle list window
-        gtk_action_activate (GTK_ACTION (applet->action_toggle_list_win));
-    }
+    
+    // Toggle list window
+    gtk_action_activate (GTK_ACTION (applet->action_toggle_list_win));
+#endif
 }
 
 G_MODULE_EXPORT void
@@ -268,6 +349,7 @@ alarm_applet_status_popup (GtkStatusIcon  *status_icon,
                            guint           activate_time,
                            gpointer        user_data)
 {
+#ifndef HAVE_APP_INDICATOR
     AlarmApplet *applet = (AlarmApplet *)user_data;
 
     gtk_menu_popup (GTK_MENU (applet->status_menu),
@@ -277,6 +359,7 @@ alarm_applet_status_popup (GtkStatusIcon  *status_icon,
                     status_icon,
                     button,
                     activate_time);
+#endif
 }
 
 /*
